@@ -2,8 +2,11 @@ var searchData=
 [
   ['managers',['Managers',['../group__Managers.html',1,'']]],
   ['mappedbytes',['mappedBytes',['../classQXmppVideoFrame.html#a75609b38f580867a1b325bc9e1a49958',1,'QXmppVideoFrame']]],
-  ['max',['max',['../classQXmppArchiveListIq.html#ac9fbd6197bed30cecccf49087c549790',1,'QXmppArchiveListIq::max()'],['../classQXmppArchiveRetrieveIq.html#a5e16c6c86587df896c4f73db33ac4cef',1,'QXmppArchiveRetrieveIq::max()']]],
+  ['marker',['marker',['../classQXmppRtpPacket.html#ae237832abd26d61c12ab07ba3ae2bd29',1,'QXmppRtpPacket']]],
+  ['max',['max',['../classQXmppResultSetQuery.html#aaa6e47f12046a80a3135c13672cb38e2',1,'QXmppResultSetQuery']]],
   ['maxptime',['maxptime',['../classQXmppJinglePayloadType.html#ab6971a4585334d2184c4a43cc65ca13f',1,'QXmppJinglePayloadType']]],
+  ['media',['Media',['../classQXmppDataForm_1_1Media.html',1,'QXmppDataForm']]],
+  ['media',['media',['../classQXmppDataForm_1_1Field.html#ad04607c2dcd793c9d210ed39ac3f0ec8',1,'QXmppDataForm::Field::media()'],['../classQXmppDataForm_1_1Media.html#a5b0b93f31928801d362573b49743a785',1,'QXmppDataForm::Media::Media()'],['../classQXmppDataForm_1_1Media.html#a9d9f91709c70e8591df3fd5d26bdaa18',1,'QXmppDataForm::Media::Media(const QXmppDataForm::Media &amp;other)']]],
   ['message',['message',['../classQXmppLogger.html#a7b9d3f1ebab11c651a26dde5b49344ce',1,'QXmppLogger']]],
   ['messagedelivered',['messageDelivered',['../classQXmppMessageReceiptManager.html#ac7940d37e55e8f424fa13cae6c6c5799',1,'QXmppMessageReceiptManager']]],
   ['messagereceived',['messageReceived',['../classQXmppClient.html#aa3023a1ba0628cff1032f86df93d7bc3',1,'QXmppClient::messageReceived()'],['../classQXmppMucRoom.html#a1308c355bdfad95e97519d991728d44c',1,'QXmppMucRoom::messageReceived()'],['../classQXmppOutgoingClient.html#a862561dc51e446669311d374fd96f060',1,'QXmppOutgoingClient::messageReceived()']]],
