@@ -7,10 +7,10 @@ var searchData=
   ['vcardupdatenone',['VCardUpdateNone',['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199ade94d49098994f9d9c63a2e3b26e85fe',1,'QXmppPresence']]],
   ['vcardupdatenophoto',['VCardUpdateNoPhoto',['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199a4d3c48d73da192a0054d24633622f564',1,'QXmppPresence']]],
   ['vcardupdatenotready',['VCardUpdateNotReady',['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199a628f45cf1da766418d773f83ba48af50',1,'QXmppPresence']]],
-  ['vcardupdatetype',['VCardUpdateType',['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199',1,'QXmppPresence::VCardUpdateType()'],['../classQXmppPresence.html#a6748358697aa99a65209c46eae053829',1,'QXmppPresence::vCardUpdateType() const ']]],
+  ['vcardupdatetype',['vCardUpdateType',['../classQXmppPresence.html#a6748358697aa99a65209c46eae053829',1,'QXmppPresence::vCardUpdateType() const '],['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199',1,'QXmppPresence::VCardUpdateType()']]],
   ['vcardupdatevalidphoto',['VCardUpdateValidPhoto',['../classQXmppPresence.html#a642a378dd425bbbda1de4317e2dcd199a77b3104e5b50933e952dd82740bbe703',1,'QXmppPresence']]],
   ['verify',['Verify',['../classQXmppDialback.html#a0448107c56f892056f359013b80798bcab04f60abfc5f6b6e0f3166e285dd78c6',1,'QXmppDialback']]],
-  ['version',['version',['../classQXmppArchiveChat.html#a2e563da62d14e284f30f1444102d05a3',1,'QXmppArchiveChat::version()'],['../classQXmppVersionIq.html#a3dc888295f2a8ea67eab86221d1f61c5',1,'QXmppVersionIq::version()']]],
+  ['version',['version',['../classQXmppRtpPacket.html#a76a810d53d0df4894b0cd4abb2872a77',1,'QXmppRtpPacket::version()'],['../classQXmppArchiveChat.html#a2e563da62d14e284f30f1444102d05a3',1,'QXmppArchiveChat::version()'],['../classQXmppVersionIq.html#a3dc888295f2a8ea67eab86221d1f61c5',1,'QXmppVersionIq::version()']]],
   ['versionmanager',['versionManager',['../classQXmppClient.html#a1ffcc6b023c8e067b2aec67a9255f1a2',1,'QXmppClient']]],
   ['versionreceived',['versionReceived',['../classQXmppVersionManager.html#a064202b4b525902fc76dc45f39a9cd8d',1,'QXmppVersionManager']]],
   ['videochannel',['videoChannel',['../classQXmppCall.html#af04eb6619344ba101dac4ead1368cd2c',1,'QXmppCall']]],
