@@ -2,24 +2,28 @@ var searchData=
 [
   ['id',['id',['../classQXmppJinglePayloadType.html#a7b2478ecef7063e99522f5a073275783',1,'QXmppJinglePayloadType::id()'],['../classQXmppJingleCandidate.html#a1b5b1cf42c9bddf16d251398c9d38f86',1,'QXmppJingleCandidate::id()'],['../classQXmppPubSubItem.html#a2f6465fa597d3b39c373f60dec8699e0',1,'QXmppPubSubItem::id()'],['../classQXmppStanza.html#ab9c0dbe7f86f9f222be28882617f8451',1,'QXmppStanza::id()']]],
   ['ignoresslerrors',['ignoreSslErrors',['../classQXmppConfiguration.html#a5b23c1bfbf43052c1de403d423967418',1,'QXmppConfiguration']]],
+  ['index',['index',['../classQXmppResultSetQuery.html#add1556addb86f5f2093c7062899d56de',1,'QXmppResultSetQuery::index()'],['../classQXmppResultSetReply.html#a05927e11e85a68b167fec152f5e8d3f7',1,'QXmppResultSetReply::index()']]],
   ['info',['info',['../classQXmppLoggable.html#ab26d53408f7ecc53a776fe2499021e03',1,'QXmppLoggable']]],
   ['inforeceived',['infoReceived',['../classQXmppDiscoveryManager.html#addbd7076f78b31433ed0a17bcae103ef',1,'QXmppDiscoveryManager']]],
   ['initiator',['initiator',['../classQXmppJingleIq.html#a84ccbc8f47dea6c39721fb20ea4b1767',1,'QXmppJingleIq']]],
-  ['instructions',['instructions',['../classQXmppDataForm.html#ab40de3c0996c5515b6fb414ec300b09d',1,'QXmppDataForm']]],
+  ['instructions',['instructions',['../classQXmppDataForm.html#ab40de3c0996c5515b6fb414ec300b09d',1,'QXmppDataForm::instructions()'],['../classQXmppRegisterIq.html#aaca06d2ab6a45aafbb7c207365b7dc33',1,'QXmppRegisterIq::instructions()']]],
   ['interfaces',['interfaces',['../classQXmppInvokable.html#a4d345ef34a91ca9e5535cef4ee6d026c',1,'QXmppInvokable']]],
   ['invitationreceived',['invitationReceived',['../classQXmppMucManager.html#a8ad1ab6b9c8bf656bedbd8cd31a0076b',1,'QXmppMucManager']]],
   ['iqreceived',['iqReceived',['../classQXmppClient.html#ab3725eaae927f9c600c59a9e7e681909',1,'QXmppClient::iqReceived()'],['../classQXmppOutgoingClient.html#ac5199200ec81a1b3de18ca8563ac430a',1,'QXmppOutgoingClient::iqReceived()']]],
   ['isattentionrequested',['isAttentionRequested',['../classQXmppMessage.html#a96902fca2931b696c874ad5b972ed0f3',1,'QXmppMessage']]],
+  ['isauthenticated',['isAuthenticated',['../classQXmppClient.html#a5337959daeec2648b3c262bc84441e44',1,'QXmppClient::isAuthenticated()'],['../classQXmppOutgoingClient.html#a009fbefdfbaef0af9846e57626048d64',1,'QXmppOutgoingClient::isAuthenticated()']]],
   ['isauthorized',['isAuthorized',['../classQXmppInvokable.html#abb8f542ae1ebd422e9454bbeafc5dda8',1,'QXmppInvokable']]],
   ['isclientvcardreceived',['isClientVCardReceived',['../classQXmppVCardManager.html#a6a9b2024738145c719623328ca13c752',1,'QXmppVCardManager']]],
   ['isconnected',['isConnected',['../classQXmppStream.html#a2fe3c35571afa33cb45efa7213b89270',1,'QXmppStream::isConnected()'],['../classQXmppIceComponent.html#acbaba98328a2f695acc9478ed7657cee',1,'QXmppIceComponent::isConnected()'],['../classQXmppIceConnection.html#a0d06b299c63a479c40a7d9980d5c68f8',1,'QXmppIceConnection::isConnected()'],['../classQXmppClient.html#adf54b0085d8a7fc81c05973973fa4a04',1,'QXmppClient::isConnected()'],['../classQXmppOutgoingClient.html#a7a4038c3d95a6d16d850f008cdc3960c',1,'QXmppOutgoingClient::isConnected()'],['../classQXmppIncomingClient.html#a635f2d9bd871807cb2ede33ed01d9a3b',1,'QXmppIncomingClient::isConnected()'],['../classQXmppIncomingServer.html#a10ef0d7a3bb32694b2b84feb2202ada7',1,'QXmppIncomingServer::isConnected()'],['../classQXmppOutgoingServer.html#a0288ad6d6e23ba3b6404fe39a5f08d4d',1,'QXmppOutgoingServer::isConnected()']]],
+  ['isdelivered',['isDelivered',['../classQXmppExtendedAddress.html#a8b58ad878eeb5b73621cd61a9228fc65',1,'QXmppExtendedAddress']]],
   ['isfinished',['isFinished',['../classQXmppPasswordReply.html#ab4149f89263f3f40aa7dfb8aa1a4a2f1',1,'QXmppPasswordReply']]],
-  ['isnull',['isNull',['../classQXmppDataForm.html#aecb3ba04afc0a9e47a3d3464434ec1dd',1,'QXmppDataForm::isNull()'],['../classQXmppJingleCandidate.html#afefdb979f71856f728b3eaee8351570e',1,'QXmppJingleCandidate::isNull()'],['../classQXmppMucItem.html#a870dc4b604aebf06248004af97456737',1,'QXmppMucItem::isNull()']]],
+  ['isnull',['isNull',['../classQXmppDataForm_1_1Media.html#a9874de4203824cfc5da2f566aa768494',1,'QXmppDataForm::Media::isNull()'],['../classQXmppDataForm.html#aecb3ba04afc0a9e47a3d3464434ec1dd',1,'QXmppDataForm::isNull()'],['../classQXmppJingleCandidate.html#afefdb979f71856f728b3eaee8351570e',1,'QXmppJingleCandidate::isNull()'],['../classQXmppMucItem.html#a870dc4b604aebf06248004af97456737',1,'QXmppMucItem::isNull()'],['../classQXmppResultSetQuery.html#a917e79c4d689ed133a59c9c0b9d597ca',1,'QXmppResultSetQuery::isNull()'],['../classQXmppResultSetReply.html#a09942a28727e935f02b2f42c404b4169',1,'QXmppResultSetReply::isNull()']]],
   ['isreceiptrequested',['isReceiptRequested',['../classQXmppMessage.html#ab3069286f4d8f0e0985d83010a5688d8',1,'QXmppMessage']]],
   ['isreceived',['isReceived',['../classQXmppArchiveMessage.html#a3c57ef45d3ccec75dd9710021ee175de',1,'QXmppArchiveMessage']]],
   ['isrequired',['isRequired',['../classQXmppDataForm_1_1Field.html#a9466d429d737776da07591c8da25e36e',1,'QXmppDataForm::Field']]],
   ['isrosterreceived',['isRosterReceived',['../classQXmppRosterManager.html#a62d70b839c626994ab6de5d02ca42c23',1,'QXmppRosterManager']]],
-  ['isvalid',['isValid',['../classQXmppVideoFrame.html#a0f36f8b6e5f7d66a45b51bac1616e168',1,'QXmppVideoFrame']]],
+  ['issequential',['isSequential',['../classQXmppRtpAudioChannel.html#a1b6e924d0fdb44c12eca6ba294816c56',1,'QXmppRtpAudioChannel']]],
+  ['isvalid',['isValid',['../classQXmppVideoFrame.html#a0f36f8b6e5f7d66a45b51bac1616e168',1,'QXmppVideoFrame::isValid()'],['../classQXmppExtendedAddress.html#a1a936dd8187f873b9df680d6b900d6da',1,'QXmppExtendedAddress::isValid()']]],
   ['item',['Item',['../classQXmppRosterIq_1_1Item.html#a42077d1368696f98eb2e68abeac4ca37',1,'QXmppRosterIq::Item']]],
   ['itemadded',['itemAdded',['../classQXmppRosterManager.html#aa02bc7a630e38d0c3c1830b34381cdb0',1,'QXmppRosterManager']]],
   ['itemchanged',['itemChanged',['../classQXmppRosterManager.html#a946fa5a6386ce44b898b70bdc0eca159',1,'QXmppRosterManager']]],
