@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *	Ian Reinhart Geiser
@@ -43,6 +43,9 @@ private slots:
     void slotFinished();
     void slotPresenceReceived(const QXmppPresence &presence);
     void slotProgress(qint64 done, qint64 total);
+
+private:
+    QXmppTransferManager *transferManager;
 };
 
 #endif // IBBCLIENT_H
