@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *	Manjeet Dahiya
@@ -33,6 +33,8 @@ int main(int argc, char *argv[])
     QXmppLogger::getLogger()->setLoggingType(QXmppLogger::FileLogging);
 
     xmppClient client;
-    client.connectToServer("talk.google.com", "qxmpp.test1@gmail.com", "qxmpp123");
+    client.setPageSize(15);
+    client.setPageDirection(xmppClient::PageBackwards);
+    client.connectToServer("qxmpp.test1@gmail.com", "qxmpp123");
     return a.exec();
 }
