@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -25,13 +25,14 @@
 #define QXMPPARCHIVEIQ_H
 
 #include "QXmppIq.h"
+#include "QXmppResultSet.h"
 
 #include <QDateTime>
 
 class QXmlStreamWriter;
 class QDomElement;
 
-/// \brief The QXmppArchiveMessage represents an archived message
+/// \brief The QXmppArchiveMessage class represents an archived message
 /// as defined by XEP-0136: Message Archiving.
 
 class QXMPP_EXPORT QXmppArchiveMessage
@@ -54,7 +55,7 @@ private:
     bool m_received;
 };
 
-/// \brief The QXmppArchiveChat represents an archived conversation
+/// \brief The QXmppArchiveChat class represents an archived conversation
 /// as defined by XEP-0136: Message Archiving.
 
 class QXMPP_EXPORT QXmppArchiveChat
@@ -82,7 +83,7 @@ public:
 
     /// \cond
     void parse(const QDomElement &element);
-    void toXml(QXmlStreamWriter *writer) const;
+    void toXml(QXmlStreamWriter *writer, const QXmppResultSetReply &rsm = QXmppResultSetReply()) const;
     /// \endcond
 
 private:
@@ -106,18 +107,20 @@ public:
     QXmppArchiveChat chat() const;
     void setChat(const QXmppArchiveChat &chat);
 
+    QXmppResultSetReply resultSetReply() const;
+    void setResultSetReply(const QXmppResultSetReply &rsm);
+
     /// \cond
     static bool isArchiveChatIq(const QDomElement &element);
-    /// \endcond
 
 protected:
-    /// \cond
     void parseElementFromChild(const QDomElement &element);
     void toXmlElementFromChild(QXmlStreamWriter *writer) const;
     /// \endcond
 
 private:
     QXmppArchiveChat m_chat;
+    QXmppResultSetReply m_rsmReply;
 };
 
 /// \brief Represents an archive list as defined by XEP-0136: Message Archiving.
@@ -132,9 +135,6 @@ public:
     QList<QXmppArchiveChat> chats() const;
     void setChats(const QList<QXmppArchiveChat> &chats);
 
-    int max() const;
-    void setMax(int max);
-
     QString with() const;
     void setWith( const QString &with );
 
@@ -144,6 +144,12 @@ public:
     QDateTime end() const;
     void setEnd(const QDateTime &end );
 
+    QXmppResultSetQuery resultSetQuery() const;
+    void setResultSetQuery(const QXmppResultSetQuery &rsm);
+
+    QXmppResultSetReply resultSetReply() const;
+    void setResultSetReply(const QXmppResultSetReply &rsm);
+
     /// \cond
     static bool isArchiveListIq(const QDomElement &element);
     /// \endcond
@@ -155,11 +161,12 @@ protected:
     /// \endcond
 
 private:
-    int m_max;
     QString m_with;
     QDateTime m_start;
     QDateTime m_end;
     QList<QXmppArchiveChat> m_chats;
+    QXmppResultSetQuery m_rsmQuery;
+    QXmppResultSetReply m_rsmReply;
 };
 
 /// \brief Represents an archive remove IQ as defined by XEP-0136: Message Archiving.
@@ -180,10 +187,8 @@ public:
 
     /// \cond
     static bool isArchiveRemoveIq(const QDomElement &element);
-    /// \endcond
 
 protected:
-    /// \cond
     void parseElementFromChild(const QDomElement &element);
     void toXmlElementFromChild(QXmlStreamWriter *writer) const;
     /// \endcond
@@ -203,29 +208,27 @@ class QXMPP_EXPORT QXmppArchiveRetrieveIq : public QXmppIq
 public:
     QXmppArchiveRetrieveIq();
 
-    int max() const;
-    void setMax(int max);
-
     QDateTime start() const;
     void setStart(const QDateTime &start);
 
     QString with() const;
     void setWith(const QString &with);
 
+    QXmppResultSetQuery resultSetQuery() const;
+    void setResultSetQuery(const QXmppResultSetQuery &rsm);
+
     /// \cond
     static bool isArchiveRetrieveIq(const QDomElement &element);
-    /// \endcond
 
 protected:
-    /// \cond
     void parseElementFromChild(const QDomElement &element);
     void toXmlElementFromChild(QXmlStreamWriter *writer) const;
     /// \endcond
 
 private:
-    int m_max;
     QString m_with;
     QDateTime m_start;
+    QXmppResultSetQuery m_rsmQuery;
 };
 
 /// \brief Represents an archive preference IQ as defined by XEP-0136: Message Archiving.
@@ -237,10 +240,8 @@ class QXMPP_EXPORT QXmppArchivePrefIq : public QXmppIq
 public:
     /// \cond
     static bool isArchivePrefIq(const QDomElement &element);
-    /// \endcond
 
 protected:
-    /// \cond
     void parseElementFromChild(const QDomElement &element);
     void toXmlElementFromChild(QXmlStreamWriter *writer) const;
     /// \endcond
