@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -37,6 +37,12 @@
 #  endif
 #endif
 
+#if defined(QXMPP_AUTOTEST_INTERNAL)
+#    define QXMPP_AUTOTEST_EXPORT QXMPP_EXPORT
+#else
+#    define QXMPP_AUTOTEST_EXPORT
+#endif
+
 /// This macro expands a numeric value of the form 0xMMNNPP (MM =
 /// major, NN = minor, PP = patch) that specifies QXmpp's version
 /// number. For example, if you compile your application against
@@ -46,7 +52,7 @@
 /// available.
 ///
 
-#define QXMPP_VERSION 0x00045c
+#define QXMPP_VERSION 0x000703
 
 QXMPP_EXPORT QString QXmppVersion();
 
