@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -28,6 +28,8 @@
 #include <QDateTime>
 #include "QXmppStanza.h"
 
+class QXmppMessagePrivate;
+
 /// \brief The QXmppMessage class represents an XMPP message.
 ///
 /// \ingroup Stanzas
@@ -60,8 +62,11 @@ public:
 
     QXmppMessage(const QString& from = "", const QString& to = "",
                  const QString& body = "", const QString& thread = "");
+    QXmppMessage(const QXmppMessage &other);
     ~QXmppMessage();
 
+    QXmppMessage& operator=(const QXmppMessage &other);
+
     QString body() const;
     void setBody(const QString&);
 
@@ -89,35 +94,16 @@ public:
     QXmppMessage::Type type() const;
     void setType(QXmppMessage::Type);
 
+    QString xhtml() const;
+    void setXhtml(const QString &xhtml);
+
     /// \cond
     void parse(const QDomElement &element);
     void toXml(QXmlStreamWriter *writer) const;
     /// \endcond
 
 private:
-    /// This enum describe a type of message timestamp.
-    enum StampType
-    {
-        LegacyDelayedDelivery,  ///< XEP-0091: Legacy Delayed Delivery
-        DelayedDelivery,        ///< XEP-0203: Delayed Delivery
-    };
-
-    QString getTypeStr() const;
-    void setTypeFromStr(const QString&);
-
-    Type m_type;
-    QDateTime m_stamp;
-    StampType m_stampType;
-    State m_state;
-
-    bool m_attentionRequested;
-    QString m_body;
-    QString m_subject;
-    QString m_thread;
-
-    // Request message receipt as per XEP-0184.
-    QString m_receiptId;
-    bool m_receiptRequested;
+    QSharedDataPointer<QXmppMessagePrivate> d;
 };
 
 #endif // QXMPPMESSAGE_H
