@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -29,19 +29,69 @@
 #include <QXmlStreamWriter>
 #include "QXmppConstants.h"
 
+static const char* presence_types[] = {
+    "error",
+    "",
+    "unavailable",
+    "subscribe",
+    "subscribed",
+    "unsubscribe",
+    "unsubscribed",
+    "probe"
+};
+
+static const char* presence_shows[] = {
+    "",
+    "away",
+    "xa",
+    "dnd",
+    "chat",
+    "invisible"
+};
+
+class QXmppPresencePrivate : public QSharedData
+{
+public:
+    QXmppPresence::AvailableStatusType availableStatusType;
+    QXmppPresence::Type type;
+    QXmppPresence::Status status;
+
+    /// XEP-0153: vCard-Based Avatars
+
+    /// photoHash: the SHA1 hash of the avatar image data itself (not the base64-encoded version)
+    /// in accordance with RFC 3174
+    QByteArray photoHash;
+    QXmppPresence::VCardUpdateType vCardUpdateType;
+
+    // XEP-0115: Entity Capabilities
+    QString capabilityHash;
+    QString capabilityNode;
+    QByteArray capabilityVer;
+    // Legacy XEP-0115: Entity Capabilities
+    QStringList capabilityExt;
+
+    // XEP-0045: Multi-User Chat
+    QXmppMucItem mucItem;
+    QList<int> mucStatusCodes;
+};
+
 /// Constructs a QXmppPresence.
 ///
 /// \param type
-/// \param status
 
-QXmppPresence::QXmppPresence(QXmppPresence::Type type,
-                             const QXmppPresence::Status& status)
-    : QXmppStanza(),
-    m_type(type),
-    m_status(status),
-    m_vCardUpdateType(VCardUpdateNone)
+QXmppPresence::QXmppPresence(QXmppPresence::Type type)
+    : d(new QXmppPresencePrivate)
 {
+    d->type = type;
+    d->vCardUpdateType = VCardUpdateNone;
+}
 
+/// Constructs a copy of \a other.
+
+QXmppPresence::QXmppPresence(const QXmppPresence &other)
+    : QXmppStanza(other)
+    , d(other.d)
+{
 }
 
 /// Destroys a QXmppPresence.
@@ -51,6 +101,62 @@ QXmppPresence::~QXmppPresence()
 
 }
 
+/// Assigns \a other to this presence.
+
+QXmppPresence &QXmppPresence::operator=(const QXmppPresence &other)
+{
+    QXmppStanza::operator=(other);
+    d = other.d;
+    return *this;
+}
+
+/// Returns the availability status type, for instance busy or away.
+///
+/// This will not tell you whether a contact is connected, check whether
+/// type() is QXmppPresence::Available instead.
+
+QXmppPresence::AvailableStatusType QXmppPresence::availableStatusType() const
+{
+    return static_cast<QXmppPresence::AvailableStatusType>(d->status.type());
+}
+
+/// Sets the availability status type, for instance busy or away.
+
+void QXmppPresence::setAvailableStatusType(AvailableStatusType type)
+{
+    d->status.setType(static_cast<QXmppPresence::Status::Type>(type));
+}
+
+/// Returns the priority level of the resource.
+
+int QXmppPresence::priority() const
+{
+    return d->status.priority();
+}
+
+/// Sets the \a priority level of the resource.
+
+void QXmppPresence::setPriority(int priority)
+{
+    d->status.setPriority(priority);
+}
+
+/// Returns the status text, a textual description of the user's status.
+
+QString QXmppPresence::statusText() const
+{
+    return d->status.statusText();
+}
+
+/// Sets the status text, a textual description of the user's status.
+///
+/// \param statusText The status text, for example "Gone fishing".
+
+void QXmppPresence::setStatusText(const QString& statusText)
+{
+    d->status.setStatusText(statusText);
+}
+
 /// Returns the presence type.
 ///
 /// You can use this method to determine the action which needs to be
@@ -60,7 +166,7 @@ QXmppPresence::~QXmppPresence()
 
 QXmppPresence::Type QXmppPresence::type() const
 {
-    return m_type;
+    return d->type;
 }
 
 /// Sets the presence type.
@@ -69,53 +175,37 @@ QXmppPresence::Type QXmppPresence::type() const
 
 void QXmppPresence::setType(QXmppPresence::Type type)
 {
-    m_type = type;
-}
-
-/// Returns the presence status.
-
-const QXmppPresence::Status& QXmppPresence::status() const
-{
-    return m_status;
-}
-
-/// Returns a reference to the presence status, allowing you to change it.
-
-QXmppPresence::Status& QXmppPresence::status()
-{
-    return m_status;
-}
-
-/// Sets the presence status.
-///
-/// \param status
-
-void QXmppPresence::setStatus(const QXmppPresence::Status& status)
-{
-    m_status = status;
+    d->type = type;
 }
 
+/// \cond
 void QXmppPresence::parse(const QDomElement &element)
 {
     QXmppStanza::parse(element);
 
-    setTypeFromStr(element.attribute("type"));
-    m_status.parse(element);
+    const QString type = element.attribute("type");
+    for (int i = Error; i <= Probe; i++) {
+        if (type == presence_types[i]) {
+            d->type = static_cast<Type>(i);
+            break;
+        }
+    }
+    d->status.parse(element);
 
     QXmppElementList extensions;
     QDomElement xElement = element.firstChildElement();
-    m_vCardUpdateType = VCardUpdateNone;
+    d->vCardUpdateType = VCardUpdateNone;
     while(!xElement.isNull())
     {
         // XEP-0045: Multi-User Chat
         if(xElement.namespaceURI() == ns_muc_user)
         {
             QDomElement itemElement = xElement.firstChildElement("item");
-            m_mucItem.parse(itemElement);
+            d->mucItem.parse(itemElement);
             QDomElement statusElement = xElement.firstChildElement("status");
-            m_mucStatusCodes.clear();
+            d->mucStatusCodes.clear();
             while (!statusElement.isNull()) {
-                m_mucStatusCodes << statusElement.attribute("code").toInt();
+                d->mucStatusCodes << statusElement.attribute("code").toInt();
                 statusElement = statusElement.nextSiblingElement("status");
             }
         }
@@ -125,25 +215,28 @@ void QXmppPresence::parse(const QDomElement &element)
             QDomElement photoElement = xElement.firstChildElement("photo");
             if(!photoElement.isNull())
             {
-                m_photoHash = QByteArray::fromHex(photoElement.text().toAscii());
-                if(m_photoHash.isEmpty())
-                    m_vCardUpdateType = VCardUpdateNoPhoto;
+                d->photoHash = QByteArray::fromHex(photoElement.text().toAscii());
+                if(d->photoHash.isEmpty())
+                    d->vCardUpdateType = VCardUpdateNoPhoto;
                 else
-                    m_vCardUpdateType = VCardUpdateValidPhoto;
+                    d->vCardUpdateType = VCardUpdateValidPhoto;
             }
             else
             {
-                m_photoHash = QByteArray();
-                m_vCardUpdateType = VCardUpdateNotReady;
+                d->photoHash = QByteArray();
+                d->vCardUpdateType = VCardUpdateNotReady;
             }
         }
         // XEP-0115: Entity Capabilities
         else if(xElement.tagName() == "c" && xElement.namespaceURI() == ns_capabilities)
         {
-            m_capabilityNode = xElement.attribute("node");
-            m_capabilityVer = QByteArray::fromBase64(xElement.attribute("ver").toAscii());
-            m_capabilityHash = xElement.attribute("hash");
-            m_capabilityExt = xElement.attribute("ext").split(" ", QString::SkipEmptyParts);
+            d->capabilityNode = xElement.attribute("node");
+            d->capabilityVer = QByteArray::fromBase64(xElement.attribute("ver").toAscii());
+            d->capabilityHash = xElement.attribute("hash");
+            d->capabilityExt = xElement.attribute("ext").split(" ", QString::SkipEmptyParts);
+        }
+        else if (xElement.tagName() == "addresses")
+        {
         }
         else if (xElement.tagName() == "error")
         {
@@ -174,19 +267,19 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
     helperToXmlAddAttribute(xmlWriter,"id", id());
     helperToXmlAddAttribute(xmlWriter,"to", to());
     helperToXmlAddAttribute(xmlWriter,"from", from());
-    helperToXmlAddAttribute(xmlWriter,"type", getTypeStr());
-    m_status.toXml(xmlWriter);
+    helperToXmlAddAttribute(xmlWriter,"type", presence_types[d->type]);
+    d->status.toXml(xmlWriter);
 
     error().toXml(xmlWriter);
 
     // XEP-0045: Multi-User Chat
-    if(!m_mucItem.isNull() || !m_mucStatusCodes.isEmpty())
+    if(!d->mucItem.isNull() || !d->mucStatusCodes.isEmpty())
     {
         xmlWriter->writeStartElement("x");
         xmlWriter->writeAttribute("xmlns", ns_muc_user);
-        if (!m_mucItem.isNull())
-            m_mucItem.toXml(xmlWriter);
-        foreach (int code, m_mucStatusCodes) {
+        if (!d->mucItem.isNull())
+            d->mucItem.toXml(xmlWriter);
+        foreach (int code, d->mucStatusCodes) {
             xmlWriter->writeStartElement("status");
             xmlWriter->writeAttribute("code", QString::number(code));
             xmlWriter->writeEndElement();
@@ -195,17 +288,17 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
     }
 
     // XEP-0153: vCard-Based Avatars
-    if(m_vCardUpdateType != VCardUpdateNone)
+    if(d->vCardUpdateType != VCardUpdateNone)
     {
         xmlWriter->writeStartElement("x");
         xmlWriter->writeAttribute("xmlns", ns_vcard_update);
-        switch(m_vCardUpdateType)
+        switch(d->vCardUpdateType)
         {
         case VCardUpdateNoPhoto:
             helperToXmlAddTextElement(xmlWriter, "photo", "");
             break;
         case VCardUpdateValidPhoto:
-            helperToXmlAddTextElement(xmlWriter, "photo", m_photoHash.toHex());
+            helperToXmlAddTextElement(xmlWriter, "photo", d->photoHash.toHex());
             break;
         case VCardUpdateNotReady:
             break;
@@ -215,188 +308,23 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
         xmlWriter->writeEndElement();
     }
 
-    if(!m_capabilityNode.isEmpty() && !m_capabilityVer.isEmpty()
-        && !m_capabilityHash.isEmpty())
+    if(!d->capabilityNode.isEmpty() && !d->capabilityVer.isEmpty()
+        && !d->capabilityHash.isEmpty())
     {
         xmlWriter->writeStartElement("c");
         xmlWriter->writeAttribute("xmlns", ns_capabilities);
-        helperToXmlAddAttribute(xmlWriter, "hash", m_capabilityHash);
-        helperToXmlAddAttribute(xmlWriter, "node", m_capabilityNode);
-        helperToXmlAddAttribute(xmlWriter, "ver", m_capabilityVer.toBase64());
+        helperToXmlAddAttribute(xmlWriter, "hash", d->capabilityHash);
+        helperToXmlAddAttribute(xmlWriter, "node", d->capabilityNode);
+        helperToXmlAddAttribute(xmlWriter, "ver", d->capabilityVer.toBase64());
         xmlWriter->writeEndElement();
     }
 
-    foreach (const QXmppElement &extension, extensions())
-        extension.toXml(xmlWriter);
+    // other extensions
+    QXmppStanza::extensionsToXml(xmlWriter);
 
     xmlWriter->writeEndElement();
 }
-
-QString QXmppPresence::getTypeStr() const
-{
-    switch(m_type) {
-    case QXmppPresence::Error:
-        return "error";
-    case QXmppPresence::Available:
-        return "";
-    case QXmppPresence::Unavailable:
-        return "unavailable";
-    case QXmppPresence::Subscribe:
-        return "subscribe";
-    case QXmppPresence::Subscribed:
-        return "subscribed";
-    case QXmppPresence::Unsubscribe:
-        return "unsubscribe";
-    case QXmppPresence::Unsubscribed:
-        return "unsubscribed";
-    case QXmppPresence::Probe:
-        return "probe";
-    default:
-        qWarning("QXmppPresence::getTypeStr() invalid type %d", (int)m_type);
-        return "";
-    }
-}
-
-void QXmppPresence::setTypeFromStr(const QString& str)
-{
-    if(str == "error")
-        m_type = QXmppPresence::Error;
-    else if(str == "")
-        m_type = QXmppPresence::Available;
-    else if(str == "unavailable")
-        m_type = QXmppPresence::Unavailable;
-    else if(str == "subscribe")
-        m_type = QXmppPresence::Subscribe;
-    else if(str == "subscribed")
-        m_type = QXmppPresence::Subscribed;
-    else if(str == "unsubscribe")
-        m_type = QXmppPresence::Unsubscribe;
-    else if(str == "unsubscribed")
-        m_type = QXmppPresence::Unsubscribed;
-    else if(str == "probe")
-        m_type = QXmppPresence::Probe;
-    else {
-        qWarning("QXmppPresence::setTypeFromStr() invalid input string type: %s",
-                 qPrintable(str));
-        m_type = QXmppPresence::Error;
-    }
-}
-
-/// Constructs a presence status.
-
-QXmppPresence::Status::Status(QXmppPresence::Status::Type type,
-                             const QString statusText, int priority) :
-                                m_type(type),
-                                m_statusText(statusText), m_priority(priority)
-{
-}
-
-/// Returns the status type, for instance busy or away.
-
-QXmppPresence::Status::Type QXmppPresence::Status::type() const
-{
-    return m_type;
-}
-
-/// Sets the status type.
-
-void QXmppPresence::Status::setType(QXmppPresence::Status::Type type)
-{
-    m_type = type;
-}
-
-void QXmppPresence::Status::setTypeFromStr(const QString& str)
-{
-    // FIXME: there is no keyword for Offline
-    if(str == "")
-        m_type = QXmppPresence::Status::Online;
-    else if(str == "away")
-        m_type = QXmppPresence::Status::Away;
-    else if(str == "chat")
-        m_type = QXmppPresence::Status::Chat;
-    else if(str == "dnd")
-        m_type = QXmppPresence::Status::DND;
-    else if(str == "xa")
-        m_type = QXmppPresence::Status::XA;
-    else {
-        qWarning("QXmppPresence::Status::setTypeFromStr() invalid input string type %s",
-            qPrintable(str));
-        m_type = QXmppPresence::Status::Online;
-    }
-}
-
-QString QXmppPresence::Status::getTypeStr() const
-{
-    switch(m_type) {
-    case QXmppPresence::Status::Online:
-        return "";
-    case QXmppPresence::Status::Offline:
-        // FIXME: there is no keyword for Offline
-        return "";
-    case QXmppPresence::Status::Away:
-        return "away";
-    case QXmppPresence::Status::XA:
-        return "xa";
-    case QXmppPresence::Status::DND:
-        return "dnd";
-    case QXmppPresence::Status::Chat:
-        return "chat";
-    default:
-        qWarning("QXmppPresence::Status::getTypeStr() invalid type %d",
-                 (int)m_type);
-        return "";
-    }
-}
-
-/// Returns the status text, a textual description of the user's status.
-
-QString QXmppPresence::Status::statusText() const
-{
-    return m_statusText;
-}
-
-/// Sets the status text, a textual description of the user's status.
-///
-/// \param str The status text, for example "Gone fishing".
-
-void QXmppPresence::Status::setStatusText(const QString& str)
-{
-    m_statusText = str;
-}
-
-/// Returns the priority level of the resource.
-
-int QXmppPresence::Status::priority() const
-{
-    return m_priority;
-}
-
-/// Sets the priority level of the resource.
-///
-/// \param priority
-
-void QXmppPresence::Status::setPriority(int priority)
-{
-    m_priority = priority;
-}
-
-void QXmppPresence::Status::parse(const QDomElement &element)
-{
-    setTypeFromStr(element.firstChildElement("show").text());
-    m_statusText = element.firstChildElement("status").text();
-    m_priority = element.firstChildElement("priority").text().toInt();
-}
-
-void QXmppPresence::Status::toXml(QXmlStreamWriter *xmlWriter) const
-{
-    const QString show = getTypeStr();
-    if (!show.isEmpty())
-        helperToXmlAddTextElement(xmlWriter, "show", getTypeStr());
-    if (!m_statusText.isEmpty())
-        helperToXmlAddTextElement(xmlWriter, "status", m_statusText);
-    if (m_priority != 0)
-        helperToXmlAddTextElement(xmlWriter, "priority", QString::number(m_priority));
-}
+/// \endcond
 
 /// Returns the photo-hash of the VCardUpdate.
 ///
@@ -404,7 +332,7 @@ void QXmppPresence::Status::toXml(QXmlStreamWriter *xmlWriter) const
 
 QByteArray QXmppPresence::photoHash() const
 {
-    return m_photoHash;
+    return d->photoHash;
 }
 
 /// Sets the photo-hash of the VCardUpdate.
@@ -413,7 +341,7 @@ QByteArray QXmppPresence::photoHash() const
 
 void QXmppPresence::setPhotoHash(const QByteArray& photoHash)
 {
-    m_photoHash = photoHash;
+    d->photoHash = photoHash;
 }
 
 /// Returns the type of VCardUpdate
@@ -422,7 +350,7 @@ void QXmppPresence::setPhotoHash(const QByteArray& photoHash)
 
 QXmppPresence::VCardUpdateType QXmppPresence::vCardUpdateType() const
 {
-    return m_vCardUpdateType;
+    return d->vCardUpdateType;
 }
 
 /// Sets the type of VCardUpdate
@@ -431,56 +359,56 @@ QXmppPresence::VCardUpdateType QXmppPresence::vCardUpdateType() const
 
 void QXmppPresence::setVCardUpdateType(VCardUpdateType type)
 {
-    m_vCardUpdateType = type;
+    d->vCardUpdateType = type;
 }
 
 /// XEP-0115: Entity Capabilities
 QString QXmppPresence::capabilityHash() const
 {
-    return m_capabilityHash;
+    return d->capabilityHash;
 }
 
 /// XEP-0115: Entity Capabilities
 void QXmppPresence::setCapabilityHash(const QString& hash)
 {
-    m_capabilityHash = hash;
+    d->capabilityHash = hash;
 }
 
 /// XEP-0115: Entity Capabilities
 QString QXmppPresence::capabilityNode() const
 {
-    return m_capabilityNode;
+    return d->capabilityNode;
 }
 
 /// XEP-0115: Entity Capabilities
 void QXmppPresence::setCapabilityNode(const QString& node)
 {
-    m_capabilityNode = node;
+    d->capabilityNode = node;
 }
 
 /// XEP-0115: Entity Capabilities
 QByteArray QXmppPresence::capabilityVer() const
 {
-    return m_capabilityVer;
+    return d->capabilityVer;
 }
 
 /// XEP-0115: Entity Capabilities
 void QXmppPresence::setCapabilityVer(const QByteArray& ver)
 {
-    m_capabilityVer = ver;
+    d->capabilityVer = ver;
 }
 
 /// Legacy XEP-0115: Entity Capabilities
 QStringList QXmppPresence::capabilityExt() const
 {
-    return m_capabilityExt;
+    return d->capabilityExt;
 }
 
 /// Returns the MUC item.
 
 QXmppMucItem QXmppPresence::mucItem() const
 {
-    return m_mucItem;
+    return d->mucItem;
 }
 
 /// Sets the MUC item.
@@ -489,14 +417,14 @@ QXmppMucItem QXmppPresence::mucItem() const
 
 void QXmppPresence::setMucItem(const QXmppMucItem &item)
 {
-    m_mucItem = item;
+    d->mucItem = item;
 }
 
 /// Returns the MUC status codes.
 
 QList<int> QXmppPresence::mucStatusCodes() const
 {
-    return m_mucStatusCodes;
+    return d->mucStatusCodes;
 }
 
 /// Sets the MUC status codes.
@@ -505,6 +433,83 @@ QList<int> QXmppPresence::mucStatusCodes() const
 
 void QXmppPresence::setMucStatusCodes(const QList<int> &codes)
 {
-    m_mucStatusCodes = codes;
+    d->mucStatusCodes = codes;
 }
 
+/// \cond
+const QXmppPresence::Status& QXmppPresence::status() const
+{
+    return d->status;
+}
+
+QXmppPresence::Status& QXmppPresence::status()
+{
+    return d->status;
+}
+
+void QXmppPresence::setStatus(const QXmppPresence::Status& status)
+{
+    d->status = status;
+}
+
+QXmppPresence::Status::Status(QXmppPresence::Status::Type type,
+                             const QString statusText, int priority) :
+                                m_type(type),
+                                m_statusText(statusText), m_priority(priority)
+{
+}
+
+QXmppPresence::Status::Type QXmppPresence::Status::type() const
+{
+    return m_type;
+}
+
+void QXmppPresence::Status::setType(QXmppPresence::Status::Type type)
+{
+    m_type = type;
+}
+
+QString QXmppPresence::Status::statusText() const
+{
+    return m_statusText;
+}
+
+void QXmppPresence::Status::setStatusText(const QString& str)
+{
+    m_statusText = str;
+}
+
+int QXmppPresence::Status::priority() const
+{
+    return m_priority;
+}
+
+void QXmppPresence::Status::setPriority(int priority)
+{
+    m_priority = priority;
+}
+
+void QXmppPresence::Status::parse(const QDomElement &element)
+{
+    const QString show = element.firstChildElement("show").text();
+    for (int i = Online; i <= Invisible; i++) {
+        if (show == presence_shows[i]) {
+            m_type = static_cast<Type>(i);
+            break;
+        }
+    }
+    m_statusText = element.firstChildElement("status").text();
+    m_priority = element.firstChildElement("priority").text().toInt();
+}
+
+void QXmppPresence::Status::toXml(QXmlStreamWriter *xmlWriter) const
+{
+    const QString show = presence_shows[m_type];
+    if (!show.isEmpty())
+        helperToXmlAddTextElement(xmlWriter, "show", show);
+    if (!m_statusText.isEmpty())
+        helperToXmlAddTextElement(xmlWriter, "status", m_statusText);
+    if (m_priority != 0)
+        helperToXmlAddTextElement(xmlWriter, "priority", QString::number(m_priority));
+}
+/// \endcond
