@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -211,18 +211,7 @@ QXmppClient::QXmppClient(QObject *parent)
     addExtension(d->versionManager);
 
     addExtension(new QXmppEntityTimeManager());
-
-    QXmppDiscoveryManager *discoveryManager = new QXmppDiscoveryManager;
-    addExtension(discoveryManager);
-
-    // obsolete signal
-    check = connect(discoveryManager, SIGNAL(infoReceived(QXmppDiscoveryIq)),
-                    this, SIGNAL(discoveryIqReceived(QXmppDiscoveryIq)));
-    Q_ASSERT(check);
-
-    check = connect(discoveryManager, SIGNAL(itemsReceived(QXmppDiscoveryIq)),
-                    this, SIGNAL(discoveryIqReceived(QXmppDiscoveryIq)));
-    Q_ASSERT(check);
+    addExtension(new QXmppDiscoveryManager());
 }
 
 /// Destructor, destroys the QXmppClient object.
@@ -352,14 +341,20 @@ void QXmppClient::disconnectFromServer()
     d->reconnectionTimer->stop();
 
     d->clientPresence.setType(QXmppPresence::Unavailable);
-    d->clientPresence.status().setType(QXmppPresence::Status::Offline);
-    d->clientPresence.status().setStatusText("Logged out");
+    d->clientPresence.setStatusText("Logged out");
     if (d->stream->isConnected())
         sendPacket(d->clientPresence);
 
     d->stream->disconnectFromHost();
 }
 
+/// Returns true if the client has authenticated with the XMPP server.
+
+bool QXmppClient::isAuthenticated() const
+{
+    return d->stream->isAuthenticated();
+}
+
 /// Returns true if the client is connected to the XMPP server.
 ///
 
@@ -536,7 +531,8 @@ void QXmppClient::_q_streamConnected()
     emit stateChanged(QXmppClient::ConnectedState);
 
     // send initial presence
-    sendPacket(d->clientPresence);
+    if (d->stream->isAuthenticated())
+        sendPacket(d->clientPresence);
 }
 
 void QXmppClient::_q_streamDisconnected()
