@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -137,6 +137,7 @@ public:
     void connectToServer(const QXmppConfiguration&,
                          const QXmppPresence& initialPresence =
                          QXmppPresence());
+    bool isAuthenticated() const;
     bool isConnected() const;
 
     QXmppPresence clientPresence() const;
@@ -212,13 +213,6 @@ signals:
     /// This signal is emitted when the client state changes.
     void stateChanged(QXmppClient::State state);
 
-    /// \cond
-    // Deprecated in release 0.3.0
-    // Use QXmppDiscoveryManager::informationReceived(const QXmppDiscoveryIq&)
-    // Notifies that an XMPP service discovery iq stanza is received.
-    void discoveryIqReceived(const QXmppDiscoveryIq&);
-    /// \endcond
-
 public slots:
     void connectToServer(const QString &jid,
                          const QString &password);
