@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Authors:
  *  Jeremy Lainé
@@ -22,7 +22,31 @@
  *
  */
 
+#include <QDomDocument>
 #include <QObject>
+#include <QtTest/QtTest>
+
+template <class T>
+static void parsePacket(T &packet, const QByteArray &xml)
+{
+    //qDebug() << "parsing" << xml;
+    QDomDocument doc;
+    QCOMPARE(doc.setContent(xml, true), true);
+    QDomElement element = doc.documentElement();
+    packet.parse(element);
+}
+
+template <class T>
+static void serializePacket(T &packet, const QByteArray &xml)
+{
+    QBuffer buffer;
+    buffer.open(QIODevice::ReadWrite);
+    QXmlStreamWriter writer(&buffer);
+    packet.toXml(&writer);
+    qDebug() << "expect " << xml;
+    qDebug() << "writing" << buffer.data();
+    QCOMPARE(buffer.data(), xml);
+}
 
 class TestUtils : public QObject
 {
@@ -30,7 +54,6 @@ class TestUtils : public QObject
 
 private slots:
     void testCrc32();
-    void testDigestMd5();
     void testHmac();
     void testJid();
     void testMime();
@@ -43,57 +66,27 @@ class TestPackets : public QObject
     Q_OBJECT
 
 private slots:
+    void testArchiveList_data();
     void testArchiveList();
+    void testArchiveChat_data();
     void testArchiveChat();
     void testArchiveRemove();
+    void testArchiveRetrieve_data();
     void testArchiveRetrieve();
     void testBindNoResource();
     void testBindResource();
     void testBindResult();
     void testDiscovery();
     void testDiscoveryWithForm();
-    void testMessage();
-    void testMessageFull();
-    void testMessageAttention();
-    void testMessageReceipt();
-    void testMessageDelay();
-    void testMessageLegacyDelay();
     void testNonSaslAuth();
-    void testPresence();
-    void testPresenceFull();
-    void testPresenceWithVCardUpdate();
-    void testPresenceWithCapability();
-    void testPresenceWithMuc();
     void testSession();
     void testStreamFeatures();
-    void testVCard();
     void testVersionGet();
     void testVersionResult();
     void testEntityTimeGet();
     void testEntityTimeResult();
 };
 
-class TestCodec : public QObject
-{
-    Q_OBJECT
-
-private slots:
-    void testTheoraDecoder();
-    void testTheoraEncoder();
-};
-
-class TestJingle : public QObject
-{
-    Q_OBJECT
-
-private slots:
-    void testSession();
-    void testTerminate();
-    void testAudioPayloadType();
-    void testVideoPayloadType();
-    void testRinging();
-};
-
 class TestPubSub : public QObject
 {
     Q_OBJECT
@@ -107,54 +100,11 @@ private slots:
     void testSubscriptions();
 };
 
-class TestRtp : public QObject
-{
-    Q_OBJECT
-
-private slots:
-    void testBad();
-    void testSimple();
-    void testWithCsrc();
-};
-
 class TestServer : public QObject
 {
     Q_OBJECT
 
 private slots:
+    void testConnect_data();
     void testConnect();
 };
-
-class TestStun : public QObject
-{
-    Q_OBJECT
-
-private slots:
-    void testFingerprint();
-    void testIntegrity();
-    void testIPv4Address();
-    void testIPv6Address();
-    void testXorIPv4Address();
-    void testXorIPv6Address();
-};
-
-class TestXmlRpc : public QObject
-{
-    Q_OBJECT
-
-private slots:
-    void testBase64();
-    void testBool();
-    void testDateTime();
-    void testDouble();
-    void testInt();
-    void testNil();
-    void testString();
-
-    void testArray();
-    void testStruct();
-
-    void testInvoke();
-    void testResponse();
-    void testResponseFault();
-};
